<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="20"/>
        <source>MX Boot Repair</source>
        <translation>MX Boot Repair</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="45"/>
        <source>MX Boot Repair is a utility that can be used to reinstall GRUB bootloader on the ESP (EFI System Partition), MBR (Master Boot Record) or root partition. It provides the option to reconstruct the GRUB configuration file and to back up and restore MBR or PBR (root).</source>
        <translation>MX Käynnistyskorjain on apuväline jota voidaan käyttää GRUB-käynnistyslataimen uudelleenasentamista vasten ESP:ssä (EFI-järjestelmäosio), MBR:ssä (Master Boot Record-pääkäynnistysio) tai root- eli juuriosiossa. Se tarjoaa uudelleenrakentamisen vaihtoehdon GRUB-asetustiedostolle sekä varmuuskopioidaksesi ja myös palauttaaksesi MBR:n tai PBR:n (root-juuri).</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="64"/>
        <source>What would you like to do?</source>
        <translation>Mitä haluaisit tehdä?</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="94"/>
        <source>Backup MBR or PBR (legacy boot only)</source>
        <translation>Varmuuskopioi MBR tai PBR (ainoastaan vanhoillinen legacy-käynnistys)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="70"/>
        <source>Reinstall GRUB bootloader on ESP, MBR or PBR (root)</source>
        <translation>Uudelleenasenna GRUB-käynnistyslataaja ESP:hen, MBR:ään tai PBR:ään (root-juuri)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="80"/>
        <source>Repair GRUB configuration file</source>
        <translation>Korjaa GRUB-asetustiedosto</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="87"/>
        <source>Regenerate initramfs images</source>
        <translation>Luo uudelleen initramfs-kuvat</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="101"/>
        <source>Restore MBR or PBR from backup (legacy boot only)</source>
        <translation>Palauta MBR tai PBR varmuuskopiosta (ainoastaan vanhoillinen legacy-käynnistys)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="134"/>
        <location filename="../src/gui/mainwindow.cpp" line="425"/>
        <source>Select Boot Method</source>
        <translation>Valitse käynnistystapa</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="152"/>
        <source>Master Boot Record</source>
        <translation>Master Boot Record</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="155"/>
        <source>MBR</source>
        <translation>MBR</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="158"/>
        <location filename="../src/gui/mainwindow.ui" line="398"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="193"/>
        <location filename="../src/gui/mainwindow.cpp" line="426"/>
        <source>Location:</source>
        <translation>Sijainti:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="218"/>
        <source>EFI System Partition</source>
        <translation>EFI Järjestelmäosio</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="221"/>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="240"/>
        <source>Root (Partition Boot Record)</source>
        <translation>Root-juuri (osion käynnistystaltio)</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="243"/>
        <location filename="../src/gui/mainwindow.cpp" line="428"/>
        <source>root</source>
        <translation>juuri</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="278"/>
        <location filename="../src/gui/mainwindow.cpp" line="433"/>
        <source>Select root location:</source>
        <translation>Valitse root-juuren kohde:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="300"/>
        <location filename="../src/gui/mainwindow.cpp" line="427"/>
        <source>Install on:</source>
        <translation>Asenna:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="389"/>
        <source>About this application</source>
        <translation>Tietoja tästä sovelluksesta</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="392"/>
        <source>About...</source>
        <translation>Tietoja...</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="440"/>
        <source>Display help </source>
        <translation>Näytä ohje</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="443"/>
        <source>Help</source>
        <translation>Ohje</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="449"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="490"/>
        <source>Cancel any changes then quit</source>
        <translation>Kumoa kaikki muutokset ja lopeta</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="493"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="499"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="518"/>
        <source>Apply any changes</source>
        <translation>Hyväksy kaikki muutokset</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.ui" line="521"/>
        <location filename="../src/gui/mainwindow.cpp" line="82"/>
        <source>Next</source>
        <translation>Seuraava</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="461"/>
        <source>Apply</source>
        <translation>Hyväksy</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="102"/>
        <source>GRUB is being installed on %1 device.</source>
        <translation>Asennetaan GRUB laitteeseen %1.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="292"/>
        <location filename="../src/gui/mainwindow.cpp" line="350"/>
        <location filename="../src/gui/mainwindow.cpp" line="466"/>
        <location filename="../src/gui/mainwindow.cpp" line="470"/>
        <location filename="../src/gui/mainwindow.cpp" line="477"/>
        <location filename="../src/gui/mainwindow.cpp" line="483"/>
        <location filename="../src/gui/mainwindow.cpp" line="491"/>
        <location filename="../src/gui/mainwindow.cpp" line="498"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="142"/>
        <source>The GRUB configuration file (grub.cfg) is being rebuilt.</source>
        <translation>GRUB-asetustiedostoa (grub.cfg) uudelleenrakennetaan.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="176"/>
        <source>Generating initramfs images on: %1</source>
        <translation>Luodaan initramfs-kuvat: %1</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="205"/>
        <source>Backing up MBR or PBR from %1 device.</source>
        <translation>Varmuuskopioidaan MBR tai PBR %1 laitteesta.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="261"/>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="262"/>
        <source>You are going to write the content of </source>
        <translation>Aiot kirjoittaa sisällön</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="262"/>
        <source> to </source>
        <translation>kohteeseen</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="263"/>
        <source>

Are you sure?</source>
        <translation>

Oletko varma?</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="269"/>
        <source>Restoring MBR/PBR from backup to %1 device.</source>
        <translation>Palautetaan MBR/PBR varmuuskopiosta laitteeseen %1.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="293"/>
        <source>Could not find EFI system partition (ESP) on any system disks. Please create an ESP and try again.</source>
        <translation>EFI-järjestelmäosiota (ESP) ei löytynyt yhdeltäkään järjestelmälevyltä. Luo ESP ja yritä uudestaan.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="305"/>
        <source>Select %1 location:</source>
        <translation>Valitse %1 sijainti:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="328"/>
        <source>Back</source>
        <translation>Takaisin</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="344"/>
        <source>Success</source>
        <translation>Onnistui</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="344"/>
        <source>Process finished with success.&lt;p&gt;&lt;b&gt;Do you want to exit MX Boot Repair?&lt;/b&gt;</source>
        <translation>Toimenpide saatettiin onnistuneesti päätökseen. &lt;p&gt;&lt;b&gt; Haluatko sulkea MX-käynnistyskorjaimen?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="350"/>
        <source>Process finished. Errors have occurred.</source>
        <translation>Toimitus päättynyt. Ilmeni virheitä.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="109"/>
        <location filename="../src/gui/mainwindow.cpp" line="150"/>
        <location filename="../src/gui/mainwindow.cpp" line="182"/>
        <source>Enter password to unlock %1 encrypted partition:</source>
        <translation>Syötä salasana avataksesi %1 salauksella varustetun osion:</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="432"/>
        <source>Select GRUB location</source>
        <translation>Valitse GRUB:in sijainti</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="441"/>
        <source>Select initramfs options</source>
        <translation>Valitse initramfs lisävalinnat</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="451"/>
        <source>Select Item to Back Up</source>
        <translation>Valitse mitä varmuuskopioidaan</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="456"/>
        <source>Select Item to Restore</source>
        <translation>Valitse mitä palautetaan</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="466"/>
        <location filename="../src/gui/mainwindow.cpp" line="477"/>
        <source>No location was selected.</source>
        <translation>Sijaintia ei valittuna.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="471"/>
        <location filename="../src/gui/mainwindow.cpp" line="484"/>
        <source>Please select the root partition of the system you want to fix.</source>
        <translation>Valitse järjestelmän root juuriosio, jonka haluat korjata.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="489"/>
        <source>Select backup file name</source>
        <translation>Valitse nimi varmuuskopiotiedostolle</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="491"/>
        <location filename="../src/gui/mainwindow.cpp" line="498"/>
        <source>No file was selected.</source>
        <translation>Ei tiedostoa valittuna.</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="496"/>
        <source>Select MBR or PBR backup file</source>
        <translation>Valitse joko MBR tai PBR varmuuskopiotiedosto</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="514"/>
        <source>About %1</source>
        <translation>%1 lisätietoja</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="516"/>
        <source>Version: </source>
        <translation>Versio: </translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="517"/>
        <source>Simple boot repair program for MX Linux</source>
        <translation>Käynnistyksen korjausohjelma MX Linuxille</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="519"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="520"/>
        <source>%1 License</source>
        <translation>%1 lupa</translation>
    </message>
    <message>
        <location filename="../src/gui/mainwindow.cpp" line="533"/>
        <source>%1 Help</source>
        <translation>%1 Apuopas</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/gui/about.cpp" line="52"/>
        <source>License</source>
        <translation>Lisenssi</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="53"/>
        <location filename="../src/gui/about.cpp" line="63"/>
        <source>Changelog</source>
        <translation>Muutosloki</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Peru</translation>
    </message>
    <message>
        <location filename="../src/gui/about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Sulje</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="86"/>
        <source>MX Boot Repair</source>
        <translation>MX Boot Repair</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="94"/>
        <source>MX Boot Repair - GUI and CLI tool for repairing GRUB bootloader</source>
        <translation>MX Boot Repair on työkalu GRUB-käynnistyksen korjaamiseen</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="99"/>
        <source>Force CLI mode</source>
        <translation>Pakota CLI-moodi</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="100"/>
        <source>Print actions without executing</source>
        <translation>Tulosta toiminnot suorittamatta niitä</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="101"/>
        <source>Do not prompt; require flags</source>
        <translation>Älä kehota; vaadi liput</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="102"/>
        <source>Action: install, repair, initramfs, backup, restore</source>
        <translation>Toiminnot: asennus, korjaus, initramfs, varmuuskopio, palautus</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="103"/>
        <source>Target for install: mbr, esp, root</source>
        <translation>Asennuskohde: mbr, esp, root</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="104"/>
        <source>Device for target (e.g., sda, sda1)</source>
        <translation>Kohde (esim. sda, sda1)</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="105"/>
        <source>Root partition (e.g., /dev/sda2)</source>
        <translation>Root juuriosio (esim. /dev/sda2)</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="106"/>
        <source>Partition to mount at /boot in chroot</source>
        <translation>Osio, joka liitetään chroot-tilassa /boot kansioon</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="107"/>
        <source>Partition to mount at /boot/efi in chroot</source>
        <translation>Osio, joka liitetään chroot-tilassa /boot/efi kansioon</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="108"/>
        <source>Path for backup/restore image</source>
        <translation>Polku varmuuskopio/palautus kuvalle</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="109"/>
        <source>Skip confirmations (for restore)</source>
        <translation>Ohita vahvistuskyselyt (palautusta varten)</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="110"/>
        <source>Enable verbose output</source>
        <translation>Näytä yksityiskohtaiset tulosteet</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="111"/>
        <source>Suppress non-error output</source>
        <translation>Ohita virheettömät tulosteet</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="121"/>
        <source>Error: --verbose and --quiet options are mutually exclusive
</source>
        <translation>Virhe: valinnat  --verbose ja --quiet ovat toisensa poissulkevia
</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="127"/>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <location filename="../src/gui/main.cpp" line="128"/>
        <source>You must run this program with admin access.</source>
        <translation>Tämä ohjelma on suoritettava järjestelmänvalvojan oikeuksilla.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="29"/>
        <source>Invalid index. Try again: </source>
        <translation>Virheellinen indeksi. Yritä uudelleen: </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="48"/>
        <source>Invalid selection. Enter a number </source>
        <translation>Virheellinen valinta. Anna numero</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="234"/>
        <source>MX Boot Repair (CLI)</source>
        <translation>MX Boot Repair (CLI)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="235"/>
        <source>1) Install GRUB</source>
        <translation>1) Asenna GRUB</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="236"/>
        <source>2) Repair GRUB (update-grub)</source>
        <translation>2) Korjaa GRUB (update-grub)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="237"/>
        <source>3) Regenerate initramfs</source>
        <translation>3) Luo initramfs uudelleen</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="238"/>
        <source>4) Backup MBR/PBR</source>
        <translation>4) Varmista MBR/PBR</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="239"/>
        <source>5) Restore MBR/PBR</source>
        <translation>5) Palauta MBR/PBR</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="240"/>
        <source>q) Quit</source>
        <translation>q) Sulje</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="241"/>
        <source>Select action [1-5 or &apos;q&apos; to quit]: </source>
        <translation>Valitse toiminto [1-5 tai &quot;q&quot; sulje]: </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="247"/>
        <source>Invalid selection. Enter 1-5 or &apos;q&apos; to quit.</source>
        <translation>Virheellinen valinta. Anna 1-5 tai &quot;q&quot; sulje.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="252"/>
        <source>Target: 0) MBR  1) ESP  2) Root</source>
        <translation>Kohde: 0) MBR  1) ESP  2) Root</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="253"/>
        <source>Select target</source>
        <translation>Valitse kohde</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="259"/>
        <location filename="../src/cli/controller.cpp" line="297"/>
        <location filename="../src/cli/controller.cpp" line="310"/>
        <source>No partitions found. Returning to main menu.</source>
        <translation>Osioita ei löytynyt. Paluu päävalikkoon.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="263"/>
        <location filename="../src/cli/controller.cpp" line="323"/>
        <location filename="../src/cli/controller.cpp" line="341"/>
        <source>No disks found. Returning to main menu.</source>
        <translation>Kiintolevyjä ei löytynyt. Paluu päävalikkoon.</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="268"/>
        <source>Select disk for MBR (e.g., sda)</source>
        <translation>Valitse kiintolevy MBR:lle (esim. sda)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="272"/>
        <source>Select partition for GRUB (e.g., sda1)</source>
        <translation>Valitse osio GRUB:lle (esim. sda1)</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="277"/>
        <source>Select root partition of installed system</source>
        <translation>Valitse asennettavan järjestelmän root juuriosio</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="298"/>
        <source>Select root partition to repair</source>
        <translation>Valitse korjattava root juuriosio</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="311"/>
        <source>Select root partition to regenerate initramfs</source>
        <translation>Valitse root juuriosio initramfs uudelleenluomista varten</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="324"/>
        <source>Select disk to back up MBR/PBR from</source>
        <translation>Valitse kiintolevy, jolta MBR/PBR varmuuskopioidaan</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="327"/>
        <source>Output file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
        <translation>Tulostustiedoston polku (tai &quot;b&quot; paluu, &quot;q&quot; sulje): </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="342"/>
        <source>Select disk to restore MBR/PBR to</source>
        <translation>Valitse kiintolevy, jolle MBR/PBR palautetaan</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="345"/>
        <source>Input backup file path (or &apos;b&apos; to go back, &apos;q&apos; to quit): </source>
        <translation>Anna varmuuskopion polku (tai &quot;b&quot; paluu, &quot;q&quot; sulje): </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="352"/>
        <source>WARNING: This will overwrite the first 446 bytes of /dev/</source>
        <translation>VAROITUS: Tämä korvaa /dev/ ensimmäiset 446 tavua</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="352"/>
        <source>. Continue? [y/N]: </source>
        <translation>. Jatketaanko? [k/E]: </translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="355"/>
        <source>yes</source>
        <comment>confirmation input: full word</comment>
        <translation>kyllä</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="356"/>
        <source>y</source>
        <comment>confirmation input: single-letter yes</comment>
        <translation>k</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="360"/>
        <source>Cancelled.</source>
        <translation>Peruutettu!</translation>
    </message>
    <message>
        <location filename="../src/cli/controller.cpp" line="367"/>
        <source>Unknown selection</source>
        <translation>Tuntematon valinta</translation>
    </message>
</context>
</TS>